/* 
 * Copyright 2005 Paul Hinds
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.tp23.antinstaller.input;

import java.io.File;
import java.util.ResourceBundle;

import org.tp23.antinstaller.InstallerContext;
import org.tp23.antinstaller.ValidationException;
import org.tp23.antinstaller.renderer.MessageRenderer;

/**
 * <p>Input type to select a directory </p>
 * <p> </p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: tp23</p>
 * @author Paul Hinds
 * @version $Id: DirectoryInput.java,v 1.5 2007/01/28 10:25:48 teknopaul Exp $
 */

public class DirectoryInput extends OSSpecific {

	private boolean abort = false;
    private String create;
    private String checkExists;

	//to detect previous installations
	private String flagFile;
	private String flagFileExistsProperty;

	public DirectoryInput() {
	}

	/**
	 * Called to validate the user input
	 */
	public boolean validate(InstallerContext cxt) throws ValidationException{
		if (getInputResult() == null)return false;
		MessageRenderer mr = cxt.getMessageRenderer();
        String selectedName = getInputResult();
        // handle no directory option
        if( "".equals(selectedName) ){
            if( InputField.isTrue(create) || InputField.isTrue(checkExists) ){
                mr.printMessage(org.tp23.antinstaller.Installer.langPack.getString("dirNotExist"));
                return false;
            }
            else {
                return true;
            }
        } 
		File file = new File(selectedName);
		if(InputField.isTrue(create)){
			if(!file.exists()){
				try {
					if(mr.prompt(org.tp23.antinstaller.Installer.langPack.getString("dirNotExistCreate") + "\n" + file.getAbsolutePath())){
						boolean ok = file.mkdirs();
						if(!ok){
							mr.printMessage(org.tp23.antinstaller.Installer.langPack.getString("dirNotCreated"));
							return false;
						}
					} else {
						//make them stay on the page until they manage to select an existent folder
						return false;
					}
				}
				catch (Exception ex) {
					mr.printMessage(org.tp23.antinstaller.Installer.langPack.getString("canNotCreateFile") + "\n" + file.getAbsolutePath());
                    //FIXME should not throw here, should do something better so users on linux can chmod where necessary
                    // then try again
					throw new ValidationException(org.tp23.antinstaller.Installer.langPack.getString("canNotCreateFile"),ex);
					
				}
			}
		}
		if(InputField.isTrue(checkExists)){
//			if( ( !file.exists() || !file.isDirectory() ) && triedToCreate){
//				//TODO add some usefull text here to explain that we can not continue
//			}
			if(!file.exists() || !file.isDirectory()){
				mr.printMessage(org.tp23.antinstaller.Installer.langPack.getString("dirNotExist") + "\n" + file.getAbsolutePath());
				return false;
			}
		}
		return true;
	}

	public boolean isAbort() {
		return abort;
	}

	public void setAbort(boolean abort) {
		this.abort = abort;
	}

    public String getCreate() {
		return create;
    }
    public void setCreate(String create) {
		this.create = create;
    }
	public void setValue(String dir){
		setInputResult(dir);
	}

	public String getCheckExists() {
		return checkExists;
	}

	public void setCheckExists(String checkExists) {
		this.checkExists = checkExists;
	}

	public String getFlagFile() {
		return flagFile;
	}

	public void setFlagFile(String flagFile) {
		this.flagFile = flagFile;
	}

    public String getFlagFileExistsProperty() {
    	return flagFileExistsProperty;
    }

    public void setFlagFileExistsProperty( String flagFileExistsProperty ) {
    	this.flagFileExistsProperty = flagFileExistsProperty;
    }

	/**
	 * Used by checkConfig to validate the configuration file.
	 * Not used at runtime.
	 * @return boolean
	 */
	public boolean validateObject() {
		if(getDisplayText() == null){
			System.out.println("Directory:displayText must be set");
			return false;
		}
		if(getProperty() == null){
			System.out.println("Directory:property must be set");
			return false;
		}
		if(getDefaultValue() == null){
			System.out.println("Directory:defaultValue must be set");
			return false;
		}
        if(getDefaultValue().equals("")){
            if( isTrue(getCreate()) || isTrue(getCheckExists()) ) {
                System.out.println("Directory:defaultValue must be set if checkExists or create are true");
                return false;
            }
        }
		if(!InputField.optionalBoolean(getCreate())){
			System.out.println("Directory:create must be true or false or null");
			return false;
		}
		if(!InputField.optionalBoolean(getCheckExists())){
			System.out.println("Directory:checkExists must be true or false or null");
			return false;
		}
		return true;
	}

	public void setInputResult(String inputResult) {
		resultContainer.setProperty(getProperty(), inputResult);

		if ( flagFile != null ) {
			File ff = new File( inputResult + File.separator + flagFile );
			Boolean ffExists = new Boolean(ff.exists());
			resultContainer.setProperty( flagFileExistsProperty, ffExists.toString() );
		}
	
	}


}
